import { Component, Inject, Output, EventEmitter } from '@angular/core';
import { Router } from '@angular/router';
import { DragulaService } from 'ng2-dragula/ng2-dragula';
var CardwallComponent = (function () {
    function CardwallComponent(router, dragulaService, cardwall_service) {
        var _this = this;
        this.router = router;
        this.dragulaService = dragulaService;
        this.cardwall_service = cardwall_service;
        this.click_card = new EventEmitter();
        this.search_text = "";
        this.advanced_search_text = "";
        dragulaService.drag.subscribe(function (value) {
            _this.onDrag(value.slice(1));
        });
        dragulaService.dropModel.subscribe(function (value) {
            _this.onDrop(value.slice(1));
        });
        dragulaService.over.subscribe(function (value) {
            _this.onOver(value.slice(1));
        });
        dragulaService.out.subscribe(function (value) {
            _this.onOut(value.slice(1));
        });
        dragulaService.removeModel.subscribe(function (value) {
            _this.onRemove(value.slice(1));
        });
        this.cardwall_data = this.cardwall_service.getData();
    }
    CardwallComponent.prototype.getCardwallData = function () {
        var cards_data = [];
        if (this.search_text != "") {
            console.log(this.search_text);
            for (var _i = 0, _a = this.cardwall_data; _i < _a.length; _i++) {
                var data = _a[_i];
                var new_cardwall = {
                    name: data.name,
                    color: data.color,
                    cards: []
                };
                var str = data.name;
                for (var _b = 0, _c = data.cards; _b < _c.length; _b++) {
                    var card = _c[_b];
                    str += card.card_no.toString() + card.status.toString();
                }
                if (str.toLowerCase().indexOf(this.search_text.toLowerCase()) > -1) {
                    new_cardwall.cards.push(data);
                }
                cards_data.push(new_cardwall);
            }
        }
        else {
            cards_data = this.cardwall_data;
        }
        return cards_data;
    };
    CardwallComponent.prototype.ngOnInit = function () {
        var today = new Date();
        for (var _i = 0, _a = this.cardwall_data; _i < _a.length; _i++) {
            var data = _a[_i];
            for (var _b = 0, _c = data.cards; _b < _c.length; _b++) {
                var card = _c[_b];
                card.color = "yellow";
                if (this.getDurationDays(today, card.date) < 150) {
                    card.color = "red";
                }
                if (this.getDurationDays(today, card.date) < 50) {
                    card.color = "deep-purple";
                }
                if (this.getDurationDays(today, card.date) < 10) {
                    card.color = "green";
                }
            }
        }
    };
    CardwallComponent.prototype.getDurationDays = function (date1, date2) {
        var firstDate = new Date(date1);
        var secondDate = new Date(date2);
        var oneDay = 24 * 60 * 60 * 1000;
        var diffDays = Math.round(Math.abs((firstDate.getTime() - secondDate.getTime()) / (oneDay)));
        return diffDays;
    };
    CardwallComponent.prototype.hasClass = function (el, name) {
        return new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)').test(el.className);
    };
    CardwallComponent.prototype.addClass = function (el, name) {
        if (!this.hasClass(el, name)) {
            el.className = el.className ? [el.className, name].join(' ') : name;
        }
    };
    CardwallComponent.prototype.removeClass = function (el, name) {
        if (this.hasClass(el, name)) {
            el.className = el.className.replace(new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)', 'g'), '');
        }
    };
    CardwallComponent.prototype.onDrag = function (args) {
        var e = args[0], el = args[1];
    };
    CardwallComponent.prototype.onDrop = function (args) {
        var e = args[0], el = args[1];
        var status = +el.id;
        var current_container = this.cardwall_data[status];
        if (current_container) {
            for (var card_index in current_container.cards) {
                var card = this.cardwall_data[el.id].cards[card_index];
                if (card.status != status && card.status != status + 1) {
                    this.cardwall_data[card.status - 1].cards.push({ card_no: card.card_no, status: card.status });
                    current_container.cards.splice(card_index, 1);
                }
                else {
                    card.status = status + 1;
                }
            }
        }
    };
    CardwallComponent.prototype.onOver = function (args) {
        var e = args[0], el = args[1], container = args[2];
    };
    CardwallComponent.prototype.onOut = function (args) {
        var e = args[0], el = args[1], container = args[2];
    };
    CardwallComponent.prototype.onRemove = function (args) {
    };
    CardwallComponent.prototype.advancedSearch = function () {
        $("#advanced-search-for-cardwall").modal('open');
    };
    CardwallComponent.prototype.doAdvancedSearch = function () {
        this.search_text = this.advanced_search_text;
    };
    CardwallComponent.prototype._click_card = function (card_data) {
        this.click_card.emit(card_data);
    };
    return CardwallComponent;
}());
export { CardwallComponent };
CardwallComponent.decorators = [
    { type: Component, args: [{
                selector: 'cardwall',
                template: "\n    <div class=\"row\">\n    \t<div class='wrapper row cardwall-wrapper'>\n    \t  <div class='cardwall-container' *ngFor=\"let container of getCardwallData(); let status=index;\">\n    \t  \t<div class=\"cardwall\">\n    \t\t  \t<h5> {{ container.name }}</h5>\n    \t\t  \t<h6> {{ container.cards.length }} </h6>\n    \t\t  \t<div class=\"cardwall-cards\" [dragula]='\"nested-bag\"' [id]=\"status\" [dragulaModel]=\"container.cards\">\n    \t\t\t    <div *ngFor='let card of container.cards'>\n    \t\t\t    \t<card [card_data]=\"card\" (click_card)=\"_click_card($event)\"></card>\n    \t\t\t    </div>\n    \t\t\t  </div>  \n    \t\t\t</div>\n    \t  </div>\n    \t</div>\n    </div>\n  ",
                styles: ["\n    .gu-mirror{position:fixed!important;margin:0!important;z-index:9999!important;opacity:.8;-ms-filter:\"progid:DXImageTransform.Microsoft.Alpha(Opacity=80)\";filter:alpha(opacity=80)}.gu-hide{display:none!important}.gu-unselectable{-webkit-user-select:none!important;-moz-user-select:none!important;-ms-user-select:none!important;user-select:none!important}.gu-transit{opacity:.2;-ms-filter:\"progid:DXImageTransform.Microsoft.Alpha(Opacity=20)\";filter:alpha(opacity=20)}.wrapper.row{display:flex}.cardwall-wrapper{width:100%;overflow-y:hidden;overflow-x:auto}.cardwall-wrapper .cardwall{height:100%;padding:0 10px 10px;border:1px solid #e9f0f1;margin:10px 0;background-color:#e9f0f1;border-radius:4px;color:#000}.cardwall-wrapper .cardwall .cardwall-cards{min-height:180px}.cardwall-wrapper .cardwall .cardwall-cards .card{margin:5px 0}.cardwall-wrapper .cardwall-container{width:23%;margin:10px 1%;min-width:185px}.cardwall-wrapper .col.s3{margin-left:initial}.advanced-search-btn{margin-top:10px}\n  "]
            },] },
];
/** @nocollapse */
CardwallComponent.ctorParameters = function () { return [
    { type: Router, },
    { type: DragulaService, },
    { type: undefined, decorators: [{ type: Inject, args: ['CardwallInterface',] },] },
]; };
CardwallComponent.propDecorators = {
    'click_card': [{ type: Output },],
};
//# sourceMappingURL=cardwall.component.js.map