import { Component, Inject, Input, Output, EventEmitter } from '@angular/core';
import { MdDialog } from '@angular/material';
import { Router } from '@angular/router';
import { DragulaService } from 'ng2-dragula/ng2-dragula';
import { NewParentDialogComponent, NewChildDialogComponent } from './index';
var DataClassificationComponent = (function () {
    function DataClassificationComponent(router, dragulaService, dialog, data_classification_service) {
        this.router = router;
        this.dragulaService = dragulaService;
        this.dialog = dialog;
        this.data_classification_service = data_classification_service;
        this.nodes = [
            {
                id: 1,
                name: 'root1',
                children: [
                    { id: 2, name: 'child1' },
                    { id: 3, name: 'child2' }
                ]
            },
            {
                id: 4,
                name: 'root2',
                children: [
                    { id: 5, name: 'child2.1' },
                    {
                        id: 6,
                        name: 'child2.2',
                        children: [
                            { id: 7, name: 'subsub' }
                        ]
                    }
                ]
            }
        ];
        this.header = "Job Classification";
        this.footer = "You can create any job and Classification, move any job to any classification";
        this.options_for_tree = {
            allowDrag: true,
            allowDrop: true
        };
        this.isOneToMany = true;
        this.isHierarchical = true;
        this.is_new_parent_available = true;
        this.is_new_child_available = true;
        this.parent = "parent";
        this.parent_description = "Please fill in the form";
        this.child = "child";
        this.child_description = "Please fill in the form";
        this.parents = [];
        this.click_card = new EventEmitter();
        this.job_title = "";
        this.job_description = "";
        this.job_categories = [];
        this.selected_category_for_job = "";
        this.search_text = "";
        this.advanced_search_text = "";
        this.nodes = this.data_classification_service.getData();
        this.isOneToMany = this.data_classification_service.isOneToMany();
        this.isHierarchical = this.data_classification_service.isHierarchical();
        this.parent = this.data_classification_service.getLabels()["parent"]["label"];
        this.parent_description = this.data_classification_service.getLabels()["parent"]["description"];
        this.child = this.data_classification_service.getLabels()["child"]["label"];
        this.child_description = this.data_classification_service.getLabels()["child"]["description"];
        this.header = this.data_classification_service.getHeader();
        this.footer = this.data_classification_service.getFooter();
        this.is_new_parent_available = this.data_classification_service.isNewParentAvailable();
        this.is_new_child_available = this.data_classification_service.isNewChildAvailable();
        var isOneToMany = this.isOneToMany;
        var isHierarchical = true;
        this.options_for_tree = {
            allowDrag: true,
            allowDrop: function (element, _a) {
                var parent = _a.parent, index = _a.index;
                // return true / false based on element, to.parent, to.index. e.g.
                return true;
            },
            actionMapping: {
                mouse: {
                    drop: function (tree, node, $event, _a) {
                        var from = _a.from, to = _a.to;
                        var new_obj = Object.assign({}, from.data);
                        var to_parent = to.parent;
                        if (!isHierarchical) {
                            while (to_parent.parent.data.name) {
                                to_parent = to_parent.parent;
                            }
                        }
                        to_parent = to_parent.data;
                        if (!isOneToMany) {
                            if (!to_parent.children) {
                                to_parent.children = [];
                            }
                            if (!confirm("Do you want to clone the job or remove from previous category?")) {
                                var from_index = from.parent.data.children.indexOf(from.data);
                                from.parent.data.children.splice(from_index, 1);
                            }
                            to_parent.children.push(new_obj);
                        }
                        else {
                            if (!to_parent.children) {
                                to_parent.children = [];
                            }
                            var from_index = from.parent.data.children.indexOf(from.data);
                            from.parent.data.children.splice(from_index, 1);
                            to_parent.children.push(new_obj);
                        }
                        console.log("from", from);
                        tree.update();
                    }
                }
            }
        };
    }
    DataClassificationComponent.prototype.ngOnInit = function () {
    };
    DataClassificationComponent.prototype.ngAfterViewInit = function () {
        $('.tree').css('height', '200px');
        $('.tree').css('overflow-y', 'auto');
        $('.tree').css('border-right', '1px solid #eee');
    };
    DataClassificationComponent.prototype.getDurationDays = function (date1, date2) {
        var firstDate = new Date(date1);
        var secondDate = new Date(date2);
        var oneDay = 24 * 60 * 60 * 1000;
        var diffDays = Math.round(Math.abs((firstDate.getTime() - secondDate.getTime()) / (oneDay)));
        return diffDays;
    };
    DataClassificationComponent.prototype.hasClass = function (el, name) {
        return new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)').test(el.className);
    };
    DataClassificationComponent.prototype.addClass = function (el, name) {
        if (!this.hasClass(el, name)) {
            el.className = el.className ? [el.className, name].join(' ') : name;
        }
    };
    DataClassificationComponent.prototype.removeClass = function (el, name) {
        if (this.hasClass(el, name)) {
            el.className = el.className.replace(new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)', 'g'), '');
        }
    };
    DataClassificationComponent.prototype.advancedSearch = function () {
        $("#advanced-search-for-cardwall").modal('open');
    };
    DataClassificationComponent.prototype.doAdvancedSearch = function () {
        this.search_text = this.advanced_search_text;
    };
    DataClassificationComponent.prototype._click_card = function (card_data) {
        this.job_title = card_data.title;
        this.job_description = card_data.description;
        this.job_categories = card_data.categories;
        this.current_job = card_data;
        $('#job-edit-dialog').modal('open');
        setTimeout(function () {
            $("#job_title_label").addClass("active");
            $("#job_description_label").addClass("active");
            $('select').material_select();
        }, 300);
    };
    DataClassificationComponent.prototype.onVisibleContainer = function (status) {
        if ($($(".cardwall-jobs")[status]).css("display") == "block") {
            $($(".cardwall-jobs")[status]).slideUp("slow");
        }
        else {
            $($(".cardwall-jobs")[status]).slideDown("slow");
        }
    };
    DataClassificationComponent.prototype.isCollapsible = function (status) {
        return !($($(".cardwall-jobs")[status]).css("display") == "block");
    };
    DataClassificationComponent.prototype.addCategoryForJob = function () {
        this.job_categories.push(this.selected_category_for_job);
        setTimeout(function () {
            $('select').material_select();
        }, 300);
    };
    DataClassificationComponent.prototype.removeCategoryForJob = function (category) {
        this.job_categories.splice(this.job_categories.indexOf(category), 1);
        setTimeout(function () {
            $('select').material_select();
        }, 300);
    };
    DataClassificationComponent.prototype.newChildModal = function () {
        var dialogRef;
        dialogRef = this.dialog.open(NewChildDialogComponent);
        dialogRef.componentInstance.title = "title";
        dialogRef.componentInstance.message = "message";
        dialogRef.componentInstance.fields_for_child = this.data_classification_service.getChildFields();
        dialogRef.componentInstance.isOneToMany = this.isOneToMany;
        dialogRef.componentInstance.child = this.child;
        dialogRef.componentInstance.child_description = this.child_description;
        dialogRef.afterClosed().subscribe(function (result) {
            console.log('Dialog Result: ${result}');
        });
    };
    DataClassificationComponent.prototype.newParentModal = function () {
        var dialogRef;
        dialogRef = this.dialog.open(NewParentDialogComponent);
        dialogRef.componentInstance.title = "title";
        dialogRef.componentInstance.message = "message";
        dialogRef.componentInstance.fields_for_parent = this.data_classification_service.getParentFields();
        dialogRef.componentInstance.parent = this.parent;
        dialogRef.componentInstance.parent_description = this.parent_description;
        dialogRef.afterClosed().subscribe(function (result) {
            console.log('Dialog Result: ${result}');
        });
    };
    DataClassificationComponent.prototype.getParents = function (parents) {
        for (var _i = 0, _a = this.nodes; _i < _a.length; _i++) {
            var node = _a[_i];
            if (node.children) {
                parents.push(node.name);
                this.getParents(node.children);
            }
        }
    };
    DataClassificationComponent.prototype.getCurrentItem = function () {
        if (this.current_item) {
            return {
                id: this.current_item.id,
                title: this.current_item.name,
                description: "adfadf askdjf laksdjf asjdlfk askldf alksdfj lkasdjflk asdlkf asd",
                due_to: "6-20-2017"
            };
        }
        else {
            return null;
        }
    };
    DataClassificationComponent.prototype.onChangeNode = function (event) {
        console.log(event);
    };
    DataClassificationComponent.prototype.onSelectItem = function (node) {
        console.log(node);
        this.current_item = node.data;
    };
    return DataClassificationComponent;
}());
export { DataClassificationComponent };
DataClassificationComponent.decorators = [
    { type: Component, args: [{
                selector: 'data-classification',
                template: "\n    <div class=\"data-classification\">\n    \t<div class=\"row header\">\n    \t\t<h1>{{ header }}</h1>\n    \t</div>\n    \t<div class=\"row navigation-bar\">\n    \t\t<button md-raised-button (click)=\"newParentModal()\" *ngIf=\"is_new_parent_available\">New {{ parent }}</button>\n    \t\t<button md-raised-button (click)=\"newChildModal()\" *ngIf=\"is_new_child_available\">New {{ child }}</button>\n    \t</div>\n    \t<div class=\"row content\">\n    \t\t<div class=\"col-sm-8\">\n    \t\t\t<tree-root class=\"tree-view\" [nodes]=\"nodes\" [options]=\"options_for_tree\">\n    \t\t\t\t<ng-template #treeNodeTemplate let-node let-index=\"index\">\n    \t\t\t    <span (click)=\"onSelectItem(node)\">{{ node.data.name }}</span>\n    \t\t\t  </ng-template>\t\t\t\t\n    \t\t\t</tree-root>\n    \t\t</div>\n    \t\t<div class=\"col-sm-4\">\n    \t\t\t<div class=\"row detail\" *ngIf=\"getCurrentItem()\">\n    \t\t\t\t<h3> # {{ getCurrentItem().id }}</h3>\n    \t\t\t\t<h5> {{ getCurrentItem().title }}</h5>\n    \t\t\t\t<p>\n    \t\t\t\t\t{{ getCurrentItem().description }}\n    \t\t\t\t</p>\n    \t\t\t\t<div class=\"due-to\"> {{ getCurrentItem().due_to }}</div>\n    \t\t\t</div>\n    \t\t</div>\n      </div>\n      <div class=\"row footer\">\n      \t{{ footer }}\n      </div>\n    </div>\n  ",
                styles: ["\n    .data-classification{width:100%}.data-classification tree-viewport div.tree{border:1px solid #000;height:150px;overflow-y:scroll}.data-classification .navigation-bar{float:right}.data-classification .row{margin-bottom:15px}.data-classification .content{clear:right;border:1px solid #eee;padding:5px 0}.data-classification .content .due-to{color:red}.data-classification .header{text-align:center}\n  "]
            },] },
];
/** @nocollapse */
DataClassificationComponent.ctorParameters = function () { return [
    { type: Router, },
    { type: DragulaService, },
    { type: MdDialog, },
    { type: undefined, decorators: [{ type: Inject, args: ['DataClassificationInterface',] },] },
]; };
DataClassificationComponent.propDecorators = {
    'nodes': [{ type: Input },],
    'click_card': [{ type: Output },],
};
//# sourceMappingURL=data_classification.component.js.map