import { Component, OnInit, Inject, Input, Output, EventEmitter } from '@angular/core';
import { Router } from '@angular/router';
import { DragulaService } from 'ng2-dragula/ng2-dragula';
import { CardwallInterface } from '../interface/cardwall.interface';
declare var $;

@Component({
  selector: 'cardwall',
  template: `
    <div class="row">
    	<div class='wrapper row cardwall-wrapper'>
    	  <div class='cardwall-container' *ngFor="let container of getCardwallData(); let status=index;">
    	  	<div class="cardwall">
    		  	<h5> {{ container.name }}</h5>
    		  	<h6> {{ container.cards.length }} </h6>
    		  	<div class="cardwall-cards" [dragula]='"nested-bag"' [id]="status" [dragulaModel]="container.cards">
    			    <div *ngFor='let card of container.cards'>
    			    	<card [card_data]="card" (click_card)="_click_card($event)"></card>
    			    </div>
    			  </div>  
    			</div>
    	  </div>
    	</div>
    </div>
  `,
  styles: [`
    .gu-mirror{position:fixed!important;margin:0!important;z-index:9999!important;opacity:.8;-ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";filter:alpha(opacity=80)}.gu-hide{display:none!important}.gu-unselectable{-webkit-user-select:none!important;-moz-user-select:none!important;-ms-user-select:none!important;user-select:none!important}.gu-transit{opacity:.2;-ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=20)";filter:alpha(opacity=20)}.wrapper.row{display:flex}.cardwall-wrapper{width:100%;overflow-y:hidden;overflow-x:auto}.cardwall-wrapper .cardwall{height:100%;padding:0 10px 10px;border:1px solid #e9f0f1;margin:10px 0;background-color:#e9f0f1;border-radius:4px;color:#000}.cardwall-wrapper .cardwall .cardwall-cards{min-height:180px}.cardwall-wrapper .cardwall .cardwall-cards .card{margin:5px 0}.cardwall-wrapper .cardwall-container{width:23%;margin:10px 1%;min-width:185px}.cardwall-wrapper .col.s3{margin-left:initial}.advanced-search-btn{margin-top:10px}
  `]
})
export class CardwallComponent implements OnInit {
  private cardwall_data : Array<any>;
  
  @Output() click_card = new EventEmitter();

  private search_text: string = "";
  private advanced_search_text: string = "";

  constructor(
    private router: Router,
    private dragulaService: DragulaService,
    @Inject('CardwallInterface') private cardwall_service:CardwallInterface
  ) {
    dragulaService.drag.subscribe((value) => {
      this.onDrag(value.slice(1));
    });      
    dragulaService.dropModel.subscribe((value) => {
      this.onDrop(value.slice(1));
    });
    dragulaService.over.subscribe((value) => {
      this.onOver(value.slice(1));
    });
    dragulaService.out.subscribe((value) => {
      this.onOut(value.slice(1));
    });    
    dragulaService.removeModel.subscribe((value) => {
      this.onRemove(value.slice(1));
    });      
    this.cardwall_data = this.cardwall_service.getData();


    

  }

  getCardwallData() {
    let cards_data = []
    if (this.search_text != "") {
      console.log(this.search_text);
      for (let data of this.cardwall_data) {
        let new_cardwall = {
          name: data.name,
          color: data.color,
          cards: []
        }
        let str : string = data.name;
        for (let card of data.cards) {
          str += card.card_no.toString() + card.status.toString()
        }  
        if (str.toLowerCase().indexOf(this.search_text.toLowerCase()) > -1){
          new_cardwall.cards.push(data);
        }
        cards_data.push(new_cardwall);
      }      

    }
    else {
      cards_data = this.cardwall_data;
    }
    return cards_data;
  }

  ngOnInit() {
    let today = new Date();
    for (let data of this.cardwall_data){
      for (let card of data.cards) {
        card.color="yellow"
        if (this.getDurationDays(today, card.date) < 150) {
         card.color = "red";
        }
        if (this.getDurationDays(today, card.date) < 50) {
         card.color = "deep-purple";
        }      
        if (this.getDurationDays(today, card.date) < 10) {
         card.color = "green";
        }
      }
    }
  }

  getDurationDays(date1, date2) {
    let firstDate = new Date(date1);
    let secondDate = new Date(date2);
    let oneDay = 24*60*60*1000;
    let diffDays = Math.round(Math.abs((firstDate.getTime() - secondDate.getTime())/(oneDay)));
    return diffDays
  }
  private hasClass(el: any, name: string) {
    return new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)').test(el.className);
  }

  private addClass(el: any, name: string) {
    if (!this.hasClass(el, name)) {
      el.className = el.className ? [el.className, name].join(' ') : name;
    }
  }

  private removeClass(el: any, name: string) {
    if (this.hasClass(el, name)) {
      el.className = el.className.replace(new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)', 'g'), '');
    }
  }

  private onDrag(args) {
    let [e, el] = args;
  }

  private onDrop(args) {
    let [e, el] = args;
    let status = +el.id;
    let current_container = this.cardwall_data[status]; 
    if (current_container) {
      for (let card_index in current_container.cards) {
        let card = this.cardwall_data[el.id].cards[card_index];
        if (card.status != status && card.status != status+1) {
          this.cardwall_data[card.status-1].cards.push(
            {card_no: card.card_no, status: card.status},
          );
          current_container.cards.splice(card_index, 1);
        }
        else {
          card.status = status + 1;
        }
      }      
    }
  }

  private onOver(args) {
    let [e, el, container] = args;
  }

  private onOut(args) {
    let [e, el, container] = args;
  }

  private onRemove(args) {

  }

  advancedSearch() {
    $("#advanced-search-for-cardwall").modal('open');
  }

  doAdvancedSearch() {
    this.search_text = this.advanced_search_text;
  }

  _click_card(card_data) {
    this.click_card.emit(card_data);
  }
}
