import { Component, OnInit, Inject, Input, Output, EventEmitter, ElementRef, ViewChild, AfterViewInit } from '@angular/core';
import { MdDialogRef, MdDialog, MdDialogConfig } from '@angular/material';
import { Router } from '@angular/router';
import { DragulaService } from 'ng2-dragula/ng2-dragula';
import { NewParentDialogComponent, NewChildDialogComponent } from './index';
import { Observable } from 'rxjs/Rx';
import { DataClassificationInterface } from '../interface/data_classification.interface';
declare var $;

@Component({
  selector: 'data-classification',
  template: `
    <div class="data-classification">
    	<div class="row header">
    		<h1>{{ header }}</h1>
    	</div>
    	<div class="row navigation-bar">
    		<button md-raised-button (click)="newParentModal()" *ngIf="is_new_parent_available">New {{ parent }}</button>
    		<button md-raised-button (click)="newChildModal()" *ngIf="is_new_child_available">New {{ child }}</button>
    	</div>
    	<div class="row content">
    		<div class="col-sm-8">
    			<tree-root class="tree-view" [nodes]="nodes" [options]="options_for_tree">
    				<ng-template #treeNodeTemplate let-node let-index="index">
    			    <span (click)="onSelectItem(node)">{{ node.data.name }}</span>
    			  </ng-template>				
    			</tree-root>
    		</div>
    		<div class="col-sm-4">
    			<div class="row detail" *ngIf="getCurrentItem()">
    				<h3> # {{ getCurrentItem().id }}</h3>
    				<h5> {{ getCurrentItem().title }}</h5>
    				<p>
    					{{ getCurrentItem().description }}
    				</p>
    				<div class="due-to"> {{ getCurrentItem().due_to }}</div>
    			</div>
    		</div>
      </div>
      <div class="row footer">
      	{{ footer }}
      </div>
    </div>
  `,
  styles: [`
    .data-classification{width:100%}.data-classification tree-viewport div.tree{border:1px solid #000;height:150px;overflow-y:scroll}.data-classification .navigation-bar{float:right}.data-classification .row{margin-bottom:15px}.data-classification .content{clear:right;border:1px solid #eee;padding:5px 0}.data-classification .content .due-to{color:red}.data-classification .header{text-align:center}
  `]
})
export class DataClassificationComponent implements OnInit, AfterViewInit {
  @Input() nodes : Array<any> = [
    {
      id: 1,
      name: 'root1',
      children: [
        { id: 2, name: 'child1' },
        { id: 3, name: 'child2' }
      ]
    },
    {
      id: 4,
      name: 'root2',
      children: [
        { id: 5, name: 'child2.1' },
        {
          id: 6,
          name: 'child2.2',
          children: [
            { id: 7, name: 'subsub' }
          ]
        }
      ]
    }
  ]
  private header : string = "Job Classification";
  private footer : string = "You can create any job and Classification, move any job to any classification";

  private options_for_tree : any = {
    allowDrag: true,
    allowDrop: true
  };

  private isOneToMany : boolean = true;
  private isHierarchical : boolean = true;
  private is_new_parent_available : boolean = true;
  private is_new_child_available : boolean = true; 
  private parent : string = "parent";
  private parent_description : string = "Please fill in the form";
  private child : string = "child";
  private child_description : string = "Please fill in the form"
  private parents : Array<string> = [];

  @Output() click_card = new EventEmitter();

  private job_title : string = "";
  private job_description: string = "";
  private job_categories : any = [];
  private selected_category_for_job : string = "";
  private current_job : any;
  private search_text: string = "";
  private advanced_search_text: string = "";
  private current_item : any;

  constructor(
    private router: Router,
    private dragulaService: DragulaService,
    private dialog: MdDialog,
    @Inject('DataClassificationInterface') private data_classification_service:DataClassificationInterface
  ) {
    this.nodes = this.data_classification_service.getData();
    this.isOneToMany = this.data_classification_service.isOneToMany();
    this.isHierarchical = this.data_classification_service.isHierarchical();
    this.parent = this.data_classification_service.getLabels()["parent"]["label"];
    this.parent_description = this.data_classification_service.getLabels()["parent"]["description"];
    this.child = this.data_classification_service.getLabels()["child"]["label"];
    this.child_description = this.data_classification_service.getLabels()["child"]["description"];
    this.header = this.data_classification_service.getHeader();
    this.footer = this.data_classification_service.getFooter();
    this.is_new_parent_available = this.data_classification_service.isNewParentAvailable();
    this.is_new_child_available = this.data_classification_service.isNewChildAvailable();
    let isOneToMany = this.isOneToMany;
    let isHierarchical = true;

    this.options_for_tree = {
      allowDrag: true,
      allowDrop: (element, { parent, index }) => {
        // return true / false based on element, to.parent, to.index. e.g.
        return true;
      },
      actionMapping: {
        mouse: {
          drop : (tree:any, node:any, $event:any, {from, to}) => {
            let new_obj = Object.assign({}, from.data)
            let to_parent : any = to.parent;            
            if (!isHierarchical) {
              while(to_parent.parent.data.name) {
                to_parent = to_parent.parent;
              }
            }
            to_parent = to_parent.data;
            if (!isOneToMany) {
              if (!to_parent.children) {
                to_parent.children = []
              }
              if(!confirm("Do you want to clone the job or remove from previous category?")) {
                let from_index = from.parent.data.children.indexOf(from.data)
                from.parent.data.children.splice(from_index, 1);
              }
              to_parent.children.push(new_obj);
            }
            else {
              if (!to_parent.children) {
                to_parent.children = []
              }
              let from_index = from.parent.data.children.indexOf(from.data)
              from.parent.data.children.splice(from_index, 1);
              to_parent.children.push(new_obj);
            }            
            console.log("from", from);
            tree.update();
          }
        }
      }
    }
  }

  ngOnInit() {
  }

  ngAfterViewInit() {
    $('.tree').css('height', '200px')
    $('.tree').css('overflow-y', 'auto')
    $('.tree').css('border-right', '1px solid #eee')
  }

  getDurationDays(date1, date2) {
    let firstDate = new Date(date1);
    let secondDate = new Date(date2);
    let oneDay = 24*60*60*1000;
    let diffDays = Math.round(Math.abs((firstDate.getTime() - secondDate.getTime())/(oneDay)));
    return diffDays
  }
  private hasClass(el: any, name: string) {
    return new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)').test(el.className);
  }

  private addClass(el: any, name: string) {
    if (!this.hasClass(el, name)) {
      el.className = el.className ? [el.className, name].join(' ') : name;
    }
  }

  private removeClass(el: any, name: string) {
    if (this.hasClass(el, name)) {
      el.className = el.className.replace(new RegExp('(?:^|\\s+)' + name + '(?:\\s+|$)', 'g'), '');
    }
  }

  advancedSearch() {
    $("#advanced-search-for-cardwall").modal('open');
  }

  doAdvancedSearch() {
    this.search_text = this.advanced_search_text;
  }

  _click_card(card_data) {
    this.job_title = card_data.title
    this.job_description = card_data.description
    this.job_categories = card_data.categories
    this.current_job = card_data
    $('#job-edit-dialog').modal('open');
    setTimeout(() => {
      $("#job_title_label").addClass("active");
      $("#job_description_label").addClass("active");
      $('select').material_select();       
    }, 300)
  }

  onVisibleContainer(status) {
    if ($($(".cardwall-jobs")[status]).css("display") == "block") {
      $($(".cardwall-jobs")[status]).slideUp("slow");
    }
    else {
      $($(".cardwall-jobs")[status]).slideDown("slow");
    }
  }
  isCollapsible(status) {
    return !($($(".cardwall-jobs")[status]).css("display") == "block");
  }

  addCategoryForJob() {
    this.job_categories.push(this.selected_category_for_job);
    setTimeout(() => {
      $('select').material_select();       
    }, 300)      
  }

  removeCategoryForJob(category) {
    this.job_categories.splice(this.job_categories.indexOf(category), 1);
    setTimeout(() => {
      $('select').material_select();       
    }, 300)      
  }

  newChildModal() {
    let dialogRef: MdDialogRef<NewChildDialogComponent>;
    dialogRef = this.dialog.open(NewChildDialogComponent);
    dialogRef.componentInstance.title = "title";
    dialogRef.componentInstance.message = "message";
    dialogRef.componentInstance.fields_for_child = this.data_classification_service.getChildFields();
    dialogRef.componentInstance.isOneToMany = this.isOneToMany;
    dialogRef.componentInstance.child = this.child;
    dialogRef.componentInstance.child_description = this.child_description;
    dialogRef.afterClosed().subscribe(result => {
      console.log('Dialog Result: ${result}');
    });    
  }

  newParentModal() {
    let dialogRef: MdDialogRef<NewParentDialogComponent>;
    dialogRef = this.dialog.open(NewParentDialogComponent);
    dialogRef.componentInstance.title = "title";
    dialogRef.componentInstance.message = "message";
    dialogRef.componentInstance.fields_for_parent = this.data_classification_service.getParentFields();
    dialogRef.componentInstance.parent = this.parent;
    dialogRef.componentInstance.parent_description = this.parent_description;
    dialogRef.afterClosed().subscribe(result => {
      console.log('Dialog Result: ${result}');
    });    
  }

  getParents(parents) {
    for (let node of this.nodes) {
      if (node.children) {
        parents.push(node.name);
        this.getParents(node.children)
      }
    }
  }

  getCurrentItem() {
    if (this.current_item) {
      return {
        id: this.current_item.id,
        title: this.current_item.name,
        description: "adfadf askdjf laksdjf asjdlfk askldf alksdfj lkasdjflk asdlkf asd",
        due_to: "6-20-2017"
      }      
    }
    else {
      return null;
    }
  }

  onChangeNode(event) {
    console.log(event);
  }

  onSelectItem(node) {
    console.log(node);
    this.current_item = node.data;
  }
}
