import { ServiceRouterCardwallInterface } from '../interface/service_router_cardwall.interface'
import { Component, OnInit, Inject, Output, EventEmitter } from '@angular/core';
import { Router } from '@angular/router';
import { DragulaService } from 'ng2-dragula/ng2-dragula';
import { CardwallComponent } from './cardwall.component';

@Component({
  selector: 'service-router-cardwall',
  template: `
    <div class="row">
    	<div class='wrapper row cardwall-wrapper'>
    	  <div class='cardwall-container' *ngFor="let container of getServiceRouterCardwallData(); let status=index;">
    	  	<div class="cardwall">
    		  	<h5> {{ container.name }}</h5>
    		  	<h6> {{ container.cards.length }} </h6>
    		  	<div class="cardwall-cards" [dragula]='"nested-bag"' [id]="status" [dragulaModel]="container.cards">
    			    <div *ngFor='let card of container.cards'>
    			    	<card [card_data]="card" (click_card)="__click_card($event, status)"></card>
    			    </div>
    			  </div>  
    			</div>
    	  </div>
    	</div>
    </div>
  `,
  styles: [`
    .gu-mirror{position:fixed!important;margin:0!important;z-index:9999!important;opacity:.8;-ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";filter:alpha(opacity=80)}.gu-hide{display:none!important}.gu-unselectable{-webkit-user-select:none!important;-moz-user-select:none!important;-ms-user-select:none!important;user-select:none!important}.gu-transit{opacity:.2;-ms-filter:"progid:DXImageTransform.Microsoft.Alpha(Opacity=20)";filter:alpha(opacity=20)}.wrapper.row{display:flex}.cardwall-wrapper{width:100%;overflow-y:hidden;overflow-x:auto}.cardwall-wrapper .cardwall{height:100%;padding:0 10px 10px;border:1px solid #e9f0f1;margin:10px 0;background-color:#e9f0f1;border-radius:4px;color:#000}.cardwall-wrapper .cardwall .cardwall-cards{min-height:180px}.cardwall-wrapper .cardwall .cardwall-cards .card{margin:5px 0}.cardwall-wrapper .cardwall-container{width:23%;margin:10px 1%;min-width:185px}.cardwall-wrapper .col.s3{margin-left:initial}.advanced-search-btn{margin-top:10px}
  `]
})
export class ServiceRouterCardwallComponent extends CardwallComponent {
  public service_router_cardwall_data : Array<any> = [];
  @Output() card_click_event = new EventEmitter();

  constructor(
    private service_router: Router,
    private service_dragulaService: DragulaService,
  	@Inject('ServiceRouterCardwallInterface') private service_router_cardwall_interface: ServiceRouterCardwallInterface
  ) { 
    super(service_router,
      service_dragulaService,
      service_router_cardwall_interface);
    for (let container of this.getCardwallData()) {
      if (this.isVisible(container.name)) {
        this.service_router_cardwall_data.push(container);
      }
    }      
  }

  isVisible(cardwall_name) {
    switch(cardwall_name) {
      case 'predispatch':
        return this.service_router_cardwall_interface.canPredispatchTicket();
      case 'dispatch':
        return this.service_router_cardwall_interface.canDispatchTicket();
      case 'parts_request':
        return this.service_router_cardwall_interface.canPriceParts();
      case 'class_a':
        return this.service_router_cardwall_interface.canReassignTechnician();
      case 'class_b':
        return this.service_router_cardwall_interface.canReassignTechnician();
      case 'class_c':
        return this.service_router_cardwall_interface.canReassignTechnician();
      case 'technician_queue':
        return this.service_router_cardwall_interface.canViewTechnicianQueue();
      case 'inspection_queue':
        return this.service_router_cardwall_interface.canViewInspections();
      case 'in_progress_queue':
        return this.service_router_cardwall_interface.canViewServiceTicketJobsInProcess();
      case 'additional_approvals':
        return this.service_router_cardwall_interface.canHandleApprovals();
      case 'completed_queue':
        return this.service_router_cardwall_interface.canViewServiceTicketComplete();
      case 'invoice':
        return this.service_router_cardwall_interface.canHandleInvoice();
      case 'closed_queue':
        return this.service_router_cardwall_interface.canViewClose();
      default:
        return false;
    }
  }

  getServiceRouterCardwallData() {
    return this.service_router_cardwall_data;
  }

  __click_card(card_data, status) {
    this.card_click_event.emit(card_data)
  }
}
